@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -47,6 +47,9 @@ from .types.admin import ListTopicsRequest
 from .types.admin import ListTopicsResponse
 from .types.admin import ListTopicSubscriptionsRequest
 from .types.admin import ListTopicSubscriptionsResponse
+from .types.admin import OperationMetadata
+from .types.admin import SeekSubscriptionRequest
+from .types.admin import SeekSubscriptionResponse
 from .types.admin import TopicPartitions
 from .types.admin import UpdateReservationRequest
 from .types.admin import UpdateSubscriptionRequest
@@ -147,6 +150,7 @@ __all__ = (
     "MessagePublishRequest",
     "MessagePublishResponse",
     "MessageResponse",
+    "OperationMetadata",
     "PartitionAssignment",
     "PartitionAssignmentAck",
     "PartitionAssignmentRequest",
@@ -159,6 +163,8 @@ __all__ = (
     "Reservation",
     "SeekRequest",
     "SeekResponse",
+    "SeekSubscriptionRequest",
+    "SeekSubscriptionResponse",
     "SequencedCommitCursorRequest",
     "SequencedCommitCursorResponse",
     "SequencedMessage",
