@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -113,6 +113,42 @@ class AdminServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return AdminServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> AdminServiceTransport:
         """Returns the transport used by the client instance.
@@ -186,6 +222,26 @@ class AdminServiceAsyncClient:
     ) -> common.Topic:
         r"""Creates a new topic.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_create_topic():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.CreateTopicRequest(
+                    parent="parent_value",
+                    topic_id="topic_id_value",
+                )
+
+                # Make the request
+                response = client.create_topic(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.CreateTopicRequest, dict]):
                 The request object. Request for CreateTopic.
@@ -224,7 +280,7 @@ class AdminServiceAsyncClient:
                 Metadata about a topic resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, topic, topic_id])
         if request is not None and has_flattened_params:
@@ -259,7 +315,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -275,6 +336,25 @@ class AdminServiceAsyncClient:
     ) -> common.Topic:
         r"""Returns the topic configuration.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_get_topic():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.GetTopicRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_topic(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.GetTopicRequest, dict]):
                 The request object. Request for GetTopic.
@@ -296,7 +376,7 @@ class AdminServiceAsyncClient:
                 Metadata about a topic resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -327,7 +407,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -344,6 +429,25 @@ class AdminServiceAsyncClient:
         r"""Returns the partition information for the requested
         topic.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_get_topic_partitions():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.GetTopicPartitionsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_topic_partitions(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.GetTopicPartitionsRequest, dict]):
                 The request object. Request for GetTopicPartitions.
@@ -365,7 +469,7 @@ class AdminServiceAsyncClient:
                 Response for GetTopicPartitions.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -396,7 +500,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -412,6 +521,26 @@ class AdminServiceAsyncClient:
     ) -> pagers.ListTopicsAsyncPager:
         r"""Returns the list of topics for the given project.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_list_topics():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.ListTopicsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_topics(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.ListTopicsRequest, dict]):
                 The request object. Request for ListTopics.
@@ -438,7 +567,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -469,12 +598,20 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListTopicsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -492,6 +629,24 @@ class AdminServiceAsyncClient:
     ) -> common.Topic:
         r"""Updates properties of the specified topic.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_update_topic():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.UpdateTopicRequest(
+                )
+
+                # Make the request
+                response = client.update_topic(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.UpdateTopicRequest, dict]):
                 The request object. Request for UpdateTopic.
@@ -520,7 +675,7 @@ class AdminServiceAsyncClient:
                 Metadata about a topic resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([topic, update_mask])
         if request is not None and has_flattened_params:
@@ -555,7 +710,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -571,6 +731,22 @@ class AdminServiceAsyncClient:
     ) -> None:
         r"""Deletes the specified topic.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_delete_topic():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.DeleteTopicRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_topic(request=request)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.DeleteTopicRequest, dict]):
                 The request object. Request for DeleteTopic.
@@ -588,7 +764,7 @@ class AdminServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -620,7 +796,10 @@ class AdminServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def list_topic_subscriptions(
@@ -635,6 +814,26 @@ class AdminServiceAsyncClient:
         r"""Lists the subscriptions attached to the specified
         topic.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_list_topic_subscriptions():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.ListTopicSubscriptionsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_topic_subscriptions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.ListTopicSubscriptionsRequest, dict]):
                 The request object. Request for ListTopicSubscriptions.
@@ -660,7 +859,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -691,12 +890,20 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListTopicSubscriptionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -715,6 +922,26 @@ class AdminServiceAsyncClient:
     ) -> common.Subscription:
         r"""Creates a new subscription.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_create_subscription():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.CreateSubscriptionRequest(
+                    parent="parent_value",
+                    subscription_id="subscription_id_value",
+                )
+
+                # Make the request
+                response = client.create_subscription(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.CreateSubscriptionRequest, dict]):
                 The request object. Request for CreateSubscription.
@@ -755,7 +982,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, subscription, subscription_id])
         if request is not None and has_flattened_params:
@@ -790,7 +1017,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -806,6 +1038,25 @@ class AdminServiceAsyncClient:
     ) -> common.Subscription:
         r"""Returns the subscription configuration.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_get_subscription():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.GetSubscriptionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_subscription(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.GetSubscriptionRequest, dict]):
                 The request object. Request for GetSubscription.
@@ -830,7 +1081,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -861,7 +1112,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -878,6 +1134,26 @@ class AdminServiceAsyncClient:
         r"""Returns the list of subscriptions for the given
         project.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_list_subscriptions():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.ListSubscriptionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_subscriptions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.ListSubscriptionsRequest, dict]):
                 The request object. Request for ListSubscriptions.
@@ -904,7 +1180,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -935,12 +1211,20 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListSubscriptionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -958,6 +1242,24 @@ class AdminServiceAsyncClient:
     ) -> common.Subscription:
         r"""Updates properties of the specified subscription.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_update_subscription():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.UpdateSubscriptionRequest(
+                )
+
+                # Make the request
+                response = client.update_subscription(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.UpdateSubscriptionRequest, dict]):
                 The request object. Request for UpdateSubscription.
@@ -988,7 +1290,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([subscription, update_mask])
         if request is not None and has_flattened_params:
@@ -1023,7 +1325,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1039,6 +1346,22 @@ class AdminServiceAsyncClient:
     ) -> None:
         r"""Deletes the specified subscription.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_delete_subscription():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.DeleteSubscriptionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_subscription(request=request)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.DeleteSubscriptionRequest, dict]):
                 The request object. Request for DeleteSubscription.
@@ -1056,7 +1379,7 @@ class AdminServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1088,7 +1411,10 @@ class AdminServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def seek_subscription(
@@ -1127,6 +1453,30 @@ class AdminServiceAsyncClient:
         will be aborted and the new invocation of seek will
         supersede it.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_seek_subscription():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.SeekSubscriptionRequest(
+                    named_target="HEAD",
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.seek_subscription(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.SeekSubscriptionRequest, dict]):
                 The request object. Request for SeekSubscription.
@@ -1163,7 +1513,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1189,6 +1544,26 @@ class AdminServiceAsyncClient:
     ) -> common.Reservation:
         r"""Creates a new reservation.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_create_reservation():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.CreateReservationRequest(
+                    parent="parent_value",
+                    reservation_id="reservation_id_value",
+                )
+
+                # Make the request
+                response = client.create_reservation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.CreateReservationRequest, dict]):
                 The request object. Request for CreateReservation.
@@ -1229,7 +1604,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, reservation, reservation_id])
         if request is not None and has_flattened_params:
@@ -1264,7 +1639,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1280,6 +1660,25 @@ class AdminServiceAsyncClient:
     ) -> common.Reservation:
         r"""Returns the reservation configuration.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_get_reservation():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.GetReservationRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_reservation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.GetReservationRequest, dict]):
                 The request object. Request for GetReservation.
@@ -1304,7 +1703,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1335,7 +1734,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1352,6 +1756,26 @@ class AdminServiceAsyncClient:
         r"""Returns the list of reservations for the given
         project.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_list_reservations():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.ListReservationsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_reservations(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.ListReservationsRequest, dict]):
                 The request object. Request for ListReservations.
@@ -1378,7 +1802,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1409,12 +1833,20 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListReservationsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1432,6 +1864,24 @@ class AdminServiceAsyncClient:
     ) -> common.Reservation:
         r"""Updates properties of the specified reservation.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_update_reservation():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.UpdateReservationRequest(
+                )
+
+                # Make the request
+                response = client.update_reservation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.UpdateReservationRequest, dict]):
                 The request object. Request for UpdateReservation.
@@ -1462,7 +1912,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([reservation, update_mask])
         if request is not None and has_flattened_params:
@@ -1497,7 +1947,12 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1513,6 +1968,22 @@ class AdminServiceAsyncClient:
     ) -> None:
         r"""Deletes the specified reservation.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_delete_reservation():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.DeleteReservationRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_reservation(request=request)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.DeleteReservationRequest, dict]):
                 The request object. Request for DeleteReservation.
@@ -1531,7 +2002,7 @@ class AdminServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1563,7 +2034,10 @@ class AdminServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def list_reservation_topics(
@@ -1578,6 +2052,26 @@ class AdminServiceAsyncClient:
         r"""Lists the topics attached to the specified
         reservation.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_list_reservation_topics():
+                # Create a client
+                client = pubsublite_v1.AdminServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.ListReservationTopicsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_reservation_topics(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.ListReservationTopicsRequest, dict]):
                 The request object. Request for ListReservationTopics.
@@ -1604,7 +2098,7 @@ class AdminServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1635,12 +2129,20 @@ class AdminServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListReservationTopicsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
