@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,8 @@ import functools
 import re
 from typing import (
     Dict,
+    Mapping,
+    Optional,
     AsyncIterable,
     Awaitable,
     AsyncIterator,
@@ -119,6 +121,42 @@ class CursorServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return CursorServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> CursorServiceTransport:
         """Returns the transport used by the client instance.
@@ -190,6 +228,35 @@ class CursorServiceAsyncClient:
         r"""Establishes a stream with the server for managing
         committed cursors.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_streaming_commit_cursor():
+                # Create a client
+                client = pubsublite_v1.CursorServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.StreamingCommitCursorRequest(
+                )
+
+                # This method expects an iterator which contains
+                # 'pubsublite_v1.StreamingCommitCursorRequest' objects
+                # Here we create a generator that yields a single `request` for
+                # demonstrative purposes.
+                requests = [request]
+
+                def request_generator():
+                    for request in requests:
+                        yield request
+
+                # Make the request
+                stream = client.streaming_commit_cursor(requests=request_generator())
+
+                # Handle the response
+                for response in stream:
+                    print(response)
+
         Args:
             requests (AsyncIterator[`google.cloud.pubsublite_v1.types.StreamingCommitCursorRequest`]):
                 The request object AsyncIterator. A request sent from the client to
@@ -216,7 +283,12 @@ class CursorServiceAsyncClient:
         )
 
         # Send the request.
-        response = rpc(requests, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            requests,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -231,6 +303,24 @@ class CursorServiceAsyncClient:
     ) -> cursor.CommitCursorResponse:
         r"""Updates the committed cursor.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_commit_cursor():
+                # Create a client
+                client = pubsublite_v1.CursorServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.CommitCursorRequest(
+                )
+
+                # Make the request
+                response = client.commit_cursor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.CommitCursorRequest, dict]):
                 The request object. Request for CommitCursor.
@@ -277,7 +367,12 @@ class CursorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -294,6 +389,26 @@ class CursorServiceAsyncClient:
         r"""Returns all committed cursor information for a
         subscription.
 
+        .. code-block:: python
+
+            from google.cloud import pubsublite_v1
+
+            def sample_list_partition_cursors():
+                # Create a client
+                client = pubsublite_v1.CursorServiceClient()
+
+                # Initialize request argument(s)
+                request = pubsublite_v1.ListPartitionCursorsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_partition_cursors(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.pubsublite_v1.types.ListPartitionCursorsRequest, dict]):
                 The request object. Request for ListPartitionCursors.
@@ -320,7 +435,7 @@ class CursorServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -364,12 +479,20 @@ class CursorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListPartitionCursorsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
