@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -86,20 +86,24 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [CursorServiceClient, CursorServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (CursorServiceClient, "grpc"),
+        (CursorServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_cursor_service_client_from_service_account_info(client_class):
+def test_cursor_service_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "pubsublite.googleapis.com:443"
+        assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -128,23 +132,31 @@ def test_cursor_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [CursorServiceClient, CursorServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (CursorServiceClient, "grpc"),
+        (CursorServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_cursor_service_client_from_service_account_file(client_class):
+def test_cursor_service_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "pubsublite.googleapis.com:443"
+        assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
 def test_cursor_service_client_get_transport_class():
@@ -492,7 +504,9 @@ def test_cursor_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -632,10 +646,17 @@ def test_cursor_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [cursor.StreamingCommitCursorRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        cursor.StreamingCommitCursorRequest,
+        dict,
+    ],
+)
 def test_streaming_commit_cursor(request_type, transport: str = "grpc"):
     client = CursorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -666,7 +687,8 @@ async def test_streaming_commit_cursor_async(
     transport: str = "grpc_asyncio", request_type=cursor.StreamingCommitCursorRequest
 ):
     client = CursorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -700,10 +722,17 @@ async def test_streaming_commit_cursor_async_from_dict():
     await test_streaming_commit_cursor_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [cursor.CommitCursorRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        cursor.CommitCursorRequest,
+        dict,
+    ],
+)
 def test_commit_cursor(request_type, transport: str = "grpc"):
     client = CursorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -729,7 +758,8 @@ def test_commit_cursor_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CursorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -745,7 +775,8 @@ async def test_commit_cursor_async(
     transport: str = "grpc_asyncio", request_type=cursor.CommitCursorRequest
 ):
     client = CursorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -775,7 +806,9 @@ async def test_commit_cursor_async_from_dict():
 
 
 def test_commit_cursor_field_headers():
-    client = CursorServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CursorServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -795,9 +828,10 @@ def test_commit_cursor_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "subscription=subscription/value",) in kw[
-        "metadata"
-    ]
+    assert (
+        "x-goog-request-params",
+        "subscription=subscription/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -826,15 +860,23 @@ async def test_commit_cursor_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "subscription=subscription/value",) in kw[
-        "metadata"
-    ]
+    assert (
+        "x-goog-request-params",
+        "subscription=subscription/value",
+    ) in kw["metadata"]
 
 
-@pytest.mark.parametrize("request_type", [cursor.ListPartitionCursorsRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        cursor.ListPartitionCursorsRequest,
+        dict,
+    ],
+)
 def test_list_partition_cursors(request_type, transport: str = "grpc"):
     client = CursorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -865,7 +907,8 @@ def test_list_partition_cursors_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = CursorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -883,7 +926,8 @@ async def test_list_partition_cursors_async(
     transport: str = "grpc_asyncio", request_type=cursor.ListPartitionCursorsRequest
 ):
     client = CursorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -918,7 +962,9 @@ async def test_list_partition_cursors_async_from_dict():
 
 
 def test_list_partition_cursors_field_headers():
-    client = CursorServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CursorServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -940,7 +986,10 @@ def test_list_partition_cursors_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -971,11 +1020,16 @@ async def test_list_partition_cursors_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 def test_list_partition_cursors_flattened():
-    client = CursorServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CursorServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -985,7 +1039,9 @@ def test_list_partition_cursors_flattened():
         call.return_value = cursor.ListPartitionCursorsResponse()
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.list_partition_cursors(parent="parent_value",)
+        client.list_partition_cursors(
+            parent="parent_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -997,13 +1053,16 @@ def test_list_partition_cursors_flattened():
 
 
 def test_list_partition_cursors_flattened_error():
-    client = CursorServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = CursorServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.list_partition_cursors(
-            cursor.ListPartitionCursorsRequest(), parent="parent_value",
+            cursor.ListPartitionCursorsRequest(),
+            parent="parent_value",
         )
 
 
@@ -1025,7 +1084,9 @@ async def test_list_partition_cursors_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.list_partition_cursors(parent="parent_value",)
+        response = await client.list_partition_cursors(
+            parent="parent_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1046,13 +1107,15 @@ async def test_list_partition_cursors_flattened_error_async():
     # fields is an error.
     with pytest.raises(ValueError):
         await client.list_partition_cursors(
-            cursor.ListPartitionCursorsRequest(), parent="parent_value",
+            cursor.ListPartitionCursorsRequest(),
+            parent="parent_value",
         )
 
 
 def test_list_partition_cursors_pager(transport_name: str = "grpc"):
     client = CursorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1070,13 +1133,20 @@ def test_list_partition_cursors_pager(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[], next_page_token="def",
+                partition_cursors=[],
+                next_page_token="def",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(),], next_page_token="ghi",
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                ],
+                next_page_token="ghi",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(), cursor.PartitionCursor(),],
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                    cursor.PartitionCursor(),
+                ],
             ),
             RuntimeError,
         )
@@ -1096,7 +1166,8 @@ def test_list_partition_cursors_pager(transport_name: str = "grpc"):
 
 def test_list_partition_cursors_pages(transport_name: str = "grpc"):
     client = CursorServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1114,13 +1185,20 @@ def test_list_partition_cursors_pages(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[], next_page_token="def",
+                partition_cursors=[],
+                next_page_token="def",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(),], next_page_token="ghi",
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                ],
+                next_page_token="ghi",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(), cursor.PartitionCursor(),],
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                    cursor.PartitionCursor(),
+                ],
             ),
             RuntimeError,
         )
@@ -1131,7 +1209,9 @@ def test_list_partition_cursors_pages(transport_name: str = "grpc"):
 
 @pytest.mark.asyncio
 async def test_list_partition_cursors_async_pager():
-    client = CursorServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = CursorServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1150,20 +1230,29 @@ async def test_list_partition_cursors_async_pager():
                 next_page_token="abc",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[], next_page_token="def",
+                partition_cursors=[],
+                next_page_token="def",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(),], next_page_token="ghi",
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                ],
+                next_page_token="ghi",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(), cursor.PartitionCursor(),],
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                    cursor.PartitionCursor(),
+                ],
             ),
             RuntimeError,
         )
-        async_pager = await client.list_partition_cursors(request={},)
+        async_pager = await client.list_partition_cursors(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -1172,7 +1261,9 @@ async def test_list_partition_cursors_async_pager():
 
 @pytest.mark.asyncio
 async def test_list_partition_cursors_async_pages():
-    client = CursorServiceAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = CursorServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1191,18 +1282,27 @@ async def test_list_partition_cursors_async_pages():
                 next_page_token="abc",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[], next_page_token="def",
+                partition_cursors=[],
+                next_page_token="def",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(),], next_page_token="ghi",
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                ],
+                next_page_token="ghi",
             ),
             cursor.ListPartitionCursorsResponse(
-                partition_cursors=[cursor.PartitionCursor(), cursor.PartitionCursor(),],
+                partition_cursors=[
+                    cursor.PartitionCursor(),
+                    cursor.PartitionCursor(),
+                ],
             ),
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.list_partition_cursors(request={})).pages:
+        async for page_ in (
+            await client.list_partition_cursors(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
@@ -1215,7 +1315,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = CursorServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1235,7 +1336,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = CursorServiceClient(client_options=options, transport=transport,)
+        client = CursorServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1251,7 +1355,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = CursorServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1294,10 +1399,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = CursorServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = CursorServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.CursorServiceGrpcTransport,)
+    client = CursorServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.CursorServiceGrpcTransport,
+    )
 
 
 def test_cursor_service_base_transport_error():
@@ -1333,6 +1456,14 @@ def test_cursor_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_cursor_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1344,7 +1475,8 @@ def test_cursor_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.CursorServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1477,24 +1609,40 @@ def test_cursor_service_grpc_transport_client_cert_source_for_mtls(transport_cla
             )
 
 
-def test_cursor_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_cursor_service_host_no_port(transport_name):
     client = CursorServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="pubsublite.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "pubsublite.googleapis.com:443"
+    assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
-def test_cursor_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_cursor_service_host_with_port(transport_name):
     client = CursorServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="pubsublite.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "pubsublite.googleapis.com:8000"
+    assert client.transport._host == ("pubsublite.googleapis.com:8000")
 
 
 def test_cursor_service_grpc_transport_channel():
@@ -1502,7 +1650,8 @@ def test_cursor_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.CursorServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1514,7 +1663,8 @@ def test_cursor_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.CursorServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1623,8 +1773,12 @@ def test_subscription_path():
     project = "squid"
     location = "clam"
     subscription = "whelk"
-    expected = "projects/{project}/locations/{location}/subscriptions/{subscription}".format(
-        project=project, location=location, subscription=subscription,
+    expected = (
+        "projects/{project}/locations/{location}/subscriptions/{subscription}".format(
+            project=project,
+            location=location,
+            subscription=subscription,
+        )
     )
     actual = CursorServiceClient.subscription_path(project, location, subscription)
     assert expected == actual
@@ -1665,7 +1819,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "winkle"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = CursorServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1683,7 +1839,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "scallop"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = CursorServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1701,7 +1859,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "squid"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = CursorServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1721,7 +1881,8 @@ def test_common_location_path():
     project = "whelk"
     location = "octopus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = CursorServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1746,7 +1907,8 @@ def test_client_with_default_client_info():
         transports.CursorServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = CursorServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1755,7 +1917,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = CursorServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1763,7 +1926,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = CursorServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
