@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -90,20 +90,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [SubscriberServiceClient, SubscriberServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (SubscriberServiceClient, "grpc"),
+        (SubscriberServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_subscriber_service_client_from_service_account_info(client_class):
+def test_subscriber_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "pubsublite.googleapis.com:443"
+        assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -132,23 +138,33 @@ def test_subscriber_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [SubscriberServiceClient, SubscriberServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (SubscriberServiceClient, "grpc"),
+        (SubscriberServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_subscriber_service_client_from_service_account_file(client_class):
+def test_subscriber_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "pubsublite.googleapis.com:443"
+        assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
 def test_subscriber_service_client_get_transport_class():
@@ -506,7 +522,9 @@ def test_subscriber_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -646,10 +664,17 @@ def test_subscriber_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [subscriber.SubscribeRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        subscriber.SubscribeRequest,
+        dict,
+    ],
+)
 def test_subscribe(request_type, transport: str = "grpc"):
     client = SubscriberServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -678,7 +703,8 @@ async def test_subscribe_async(
     transport: str = "grpc_asyncio", request_type=subscriber.SubscribeRequest
 ):
     client = SubscriberServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -717,7 +743,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = SubscriberServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -737,7 +764,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = SubscriberServiceClient(client_options=options, transport=transport,)
+        client = SubscriberServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -753,7 +783,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = SubscriberServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -796,10 +827,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = SubscriberServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = SubscriberServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.SubscriberServiceGrpcTransport,)
+    client = SubscriberServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.SubscriberServiceGrpcTransport,
+    )
 
 
 def test_subscriber_service_base_transport_error():
@@ -831,6 +880,14 @@ def test_subscriber_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_subscriber_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -842,7 +899,8 @@ def test_subscriber_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.SubscriberServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -975,24 +1033,40 @@ def test_subscriber_service_grpc_transport_client_cert_source_for_mtls(transport
             )
 
 
-def test_subscriber_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_subscriber_service_host_no_port(transport_name):
     client = SubscriberServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="pubsublite.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "pubsublite.googleapis.com:443"
+    assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
-def test_subscriber_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_subscriber_service_host_with_port(transport_name):
     client = SubscriberServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="pubsublite.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "pubsublite.googleapis.com:8000"
+    assert client.transport._host == ("pubsublite.googleapis.com:8000")
 
 
 def test_subscriber_service_grpc_transport_channel():
@@ -1000,7 +1074,8 @@ def test_subscriber_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.SubscriberServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1012,7 +1087,8 @@ def test_subscriber_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.SubscriberServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1141,7 +1217,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = SubscriberServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1159,7 +1237,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = SubscriberServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1177,7 +1257,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = SubscriberServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1197,7 +1279,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = SubscriberServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1222,7 +1305,8 @@ def test_client_with_default_client_info():
         transports.SubscriberServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = SubscriberServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1231,7 +1315,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = SubscriberServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1239,7 +1324,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = SubscriberServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
