@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -91,20 +91,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [TopicStatsServiceClient, TopicStatsServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (TopicStatsServiceClient, "grpc"),
+        (TopicStatsServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_topic_stats_service_client_from_service_account_info(client_class):
+def test_topic_stats_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "pubsublite.googleapis.com:443"
+        assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -133,23 +139,33 @@ def test_topic_stats_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [TopicStatsServiceClient, TopicStatsServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (TopicStatsServiceClient, "grpc"),
+        (TopicStatsServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_topic_stats_service_client_from_service_account_file(client_class):
+def test_topic_stats_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "pubsublite.googleapis.com:443"
+        assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
 def test_topic_stats_service_client_get_transport_class():
@@ -507,7 +523,9 @@ def test_topic_stats_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -648,11 +666,16 @@ def test_topic_stats_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [topic_stats.ComputeMessageStatsRequest, dict,]
+    "request_type",
+    [
+        topic_stats.ComputeMessageStatsRequest,
+        dict,
+    ],
 )
 def test_compute_message_stats(request_type, transport: str = "grpc"):
     client = TopicStatsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -665,7 +688,8 @@ def test_compute_message_stats(request_type, transport: str = "grpc"):
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = topic_stats.ComputeMessageStatsResponse(
-            message_count=1389, message_bytes=1387,
+            message_count=1389,
+            message_bytes=1387,
         )
         response = client.compute_message_stats(request)
 
@@ -684,7 +708,8 @@ def test_compute_message_stats_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = TopicStatsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -702,7 +727,8 @@ async def test_compute_message_stats_async(
     transport: str = "grpc_asyncio", request_type=topic_stats.ComputeMessageStatsRequest
 ):
     client = TopicStatsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -716,7 +742,8 @@ async def test_compute_message_stats_async(
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             topic_stats.ComputeMessageStatsResponse(
-                message_count=1389, message_bytes=1387,
+                message_count=1389,
+                message_bytes=1387,
             )
         )
         response = await client.compute_message_stats(request)
@@ -738,7 +765,9 @@ async def test_compute_message_stats_async_from_dict():
 
 
 def test_compute_message_stats_field_headers():
-    client = TopicStatsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TopicStatsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -760,7 +789,10 @@ def test_compute_message_stats_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "topic=topic/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "topic=topic/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -791,13 +823,23 @@ async def test_compute_message_stats_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "topic=topic/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "topic=topic/value",
+    ) in kw["metadata"]
 
 
-@pytest.mark.parametrize("request_type", [topic_stats.ComputeHeadCursorRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        topic_stats.ComputeHeadCursorRequest,
+        dict,
+    ],
+)
 def test_compute_head_cursor(request_type, transport: str = "grpc"):
     client = TopicStatsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -825,7 +867,8 @@ def test_compute_head_cursor_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = TopicStatsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -843,7 +886,8 @@ async def test_compute_head_cursor_async(
     transport: str = "grpc_asyncio", request_type=topic_stats.ComputeHeadCursorRequest
 ):
     client = TopicStatsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -875,7 +919,9 @@ async def test_compute_head_cursor_async_from_dict():
 
 
 def test_compute_head_cursor_field_headers():
-    client = TopicStatsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TopicStatsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -897,7 +943,10 @@ def test_compute_head_cursor_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "topic=topic/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "topic=topic/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -928,13 +977,23 @@ async def test_compute_head_cursor_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "topic=topic/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "topic=topic/value",
+    ) in kw["metadata"]
 
 
-@pytest.mark.parametrize("request_type", [topic_stats.ComputeTimeCursorRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        topic_stats.ComputeTimeCursorRequest,
+        dict,
+    ],
+)
 def test_compute_time_cursor(request_type, transport: str = "grpc"):
     client = TopicStatsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -962,7 +1021,8 @@ def test_compute_time_cursor_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = TopicStatsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -980,7 +1040,8 @@ async def test_compute_time_cursor_async(
     transport: str = "grpc_asyncio", request_type=topic_stats.ComputeTimeCursorRequest
 ):
     client = TopicStatsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1012,7 +1073,9 @@ async def test_compute_time_cursor_async_from_dict():
 
 
 def test_compute_time_cursor_field_headers():
-    client = TopicStatsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TopicStatsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -1034,7 +1097,10 @@ def test_compute_time_cursor_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "topic=topic/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "topic=topic/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1065,7 +1131,10 @@ async def test_compute_time_cursor_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "topic=topic/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "topic=topic/value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -1075,7 +1144,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = TopicStatsServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1095,7 +1165,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = TopicStatsServiceClient(client_options=options, transport=transport,)
+        client = TopicStatsServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1111,7 +1184,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = TopicStatsServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1154,10 +1228,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = TopicStatsServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = TopicStatsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.TopicStatsServiceGrpcTransport,)
+    client = TopicStatsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.TopicStatsServiceGrpcTransport,
+    )
 
 
 def test_topic_stats_service_base_transport_error():
@@ -1193,6 +1285,14 @@ def test_topic_stats_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_topic_stats_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1204,7 +1304,8 @@ def test_topic_stats_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TopicStatsServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1339,24 +1440,40 @@ def test_topic_stats_service_grpc_transport_client_cert_source_for_mtls(
             )
 
 
-def test_topic_stats_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_topic_stats_service_host_no_port(transport_name):
     client = TopicStatsServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="pubsublite.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "pubsublite.googleapis.com:443"
+    assert client.transport._host == ("pubsublite.googleapis.com:443")
 
 
-def test_topic_stats_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_topic_stats_service_host_with_port(transport_name):
     client = TopicStatsServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="pubsublite.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "pubsublite.googleapis.com:8000"
+    assert client.transport._host == ("pubsublite.googleapis.com:8000")
 
 
 def test_topic_stats_service_grpc_transport_channel():
@@ -1364,7 +1481,8 @@ def test_topic_stats_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.TopicStatsServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1376,7 +1494,8 @@ def test_topic_stats_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.TopicStatsServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1488,7 +1607,9 @@ def test_topic_path():
     location = "clam"
     topic = "whelk"
     expected = "projects/{project}/locations/{location}/topics/{topic}".format(
-        project=project, location=location, topic=topic,
+        project=project,
+        location=location,
+        topic=topic,
     )
     actual = TopicStatsServiceClient.topic_path(project, location, topic)
     assert expected == actual
@@ -1529,7 +1650,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "winkle"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = TopicStatsServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1547,7 +1670,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "scallop"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = TopicStatsServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1565,7 +1690,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "squid"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = TopicStatsServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1585,7 +1712,8 @@ def test_common_location_path():
     project = "whelk"
     location = "octopus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = TopicStatsServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1610,7 +1738,8 @@ def test_client_with_default_client_info():
         transports.TopicStatsServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = TopicStatsServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1619,7 +1748,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = TopicStatsServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1627,7 +1757,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = TopicStatsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
